# spec file for php-pecl-mysqlnd-qc
#
# Copyright (c) 2011-2014 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/3.0/
#
# Please, preserve the changelog entries
#
%{!?php_inidir:  %global php_inidir       %{_sysconfdir}/php.d}
%{!?php_incldir: %global php_incldir      %{_includedir}/php}
%{!?__pecl:      %global __pecl           %{_bindir}/pecl}
%{!?__php:       %global __php            %{_bindir}/php}

%global pecl_name mysqlnd_qc
%global prever    alpha
%global with_zts  0%{?__ztsphp:1}
%if "%{php_version}" < "5.6"
# After sqlite3 mysqlnd
%global ini_name  %{pecl_name}.ini
%else
# After 20-sqlite3, 20-mysqlnd
%global ini_name  40-%{pecl_name}.ini
%endif

Summary:      A query cache plugin for mysqlnd
Name:         php-pecl-mysqlnd-qc
Version:      1.2.0
Release:      8%{?dist}
License:      PHP
Group:        Development/Languages
URL:          http://pecl.php.net/package/mysqlnd_qc

Source0:      http://pecl.php.net/get/%{pecl_name}-%{version}.tgz
# From http://www.php.net/manual/en/mysqlnd-qc.configuration.php
Source1:      mysqlnd_qc.ini
# Apache configuration for the web panel
Source2:      httpd.conf

# http://svn.php.net/viewvc?view=revision&revision=333056
# Fix for PHP 5.6
Patch0:       %{pecl_name}-svn.patch

BuildRequires: php-devel >= 5.3.4
BuildRequires: php-mysqlnd
BuildRequires: php-pear
BuildRequires: libmemcached-devel >= 0.38
BuildRequires: sqlite-devel >= 3.5.9

Requires(post): %{__pecl}
Requires(postun): %{__pecl}

Requires:     php-mysqlnd%{?_isa}
Requires:     php-sqlite3%{?_isa}
Requires:     php(zend-abi) = %{php_zend_api}
Requires:     php(api) = %{php_core_api}

Provides:     php-%{pecl_name} = %{version}
Provides:     php-%{pecl_name}%{?_isa} = %{version}
Provides:     php-pecl(%{pecl_name}) = %{version}
Provides:     php-pecl(%{pecl_name})%{?_isa} = %{version}

%if 0%{?fedora} < 20 && 0%{?rhel} < 7
# Filter private shared
%{?filter_provides_in: %filter_provides_in %{_libdir}/.*\.so$}
%{?filter_setup}
%endif


%description
The mysqlnd query result cache plugin is a mysqlnd plugin. 
It adds basic client side result set caching to all PHP MySQL extensions
(ext/mysql, ext/mysqli, PDO_MySQL). if they are compiled to use mysqlnd.
It does not change the API of the MySQL extensions and thus it operates
virtually transparent for applications.

Documentation : http://www.php.net/mysqlnd_qc

%package devel
Summary:       Mysqlnd_qc developer files (header)
Group:         Development/Libraries
Requires:      php-pecl-mysqlnd-qc%{?_isa} = %{version}-%{release}
Requires:      php-devel

%description devel
These are the files needed to compile programs using mysqlnd_qc extension.


%package -n mysqlnd-qc-panel
Summary:       Mysqlnd Query Cache Monitor
Group:         Applications/Internet
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
BuildArch:     noarch
%endif
Requires:      %{name} = %{version}-%{release}
Requires:      mod_php
Requires:      httpd

%description -n %{?scl_prefix}mysqlnd-qc-panel
This package provides the Mysqlnd Query Cache Monitor, with Apache
configuration, available on http://localhost/mysqlnd-qc/


%prep 
%setup -c -q

mv %{pecl_name}-%{version} NTS
cd NTS
%patch0 -p3 -b .svn

# Check version (often broken)
extver=$(sed -n '/#define MYSQLND_QC_VERSION_STR/{s/.* "//;s/".*$//;p}' php_mysqlnd_qc.h)
if test "x${extver}" != "x%{version}%{?prever:-}%{?prever}"; then
   : Error: Upstream %{pecl_name} version is now ${extver}, expecting %{version}%{?prever}.
   : Update the pdover macro and rebuild.
   exit 1
fi
cd ..

cp %{SOURCE1} %{ini_name}
sed -e 's:@DATADIR@:%{_datadir}:' \
    %{SOURCE2} >httpd.conf

%if %{with_zts}
# Build ZTS extension if ZTS devel available
cp -r NTS ZTS
%endif


%build
# required by libmemcached
LIBS="-lpthread"
export LIBS

peclconf() {
# don't use --enable-mysqlnd-qc-apc because:
# APC is onlysupported if both APC and MySQL Query Cache are compiled statically
%configure \
    --with-libdir=%{_lib} \
    --enable-mysqlnd-qc \
    --enable-mysqlnd-qc-memcache \
    --with-libmemcached-dir=%{_prefix} \
    --enable-mysqlnd-qc-sqlite \
    --with-sqlite-dir=%{_prefix} \
    --with-php-config=$1
}

cd NTS
%{_bindir}/phpize
peclconf %{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
peclconf %{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
make install -C NTS INSTALL_ROOT=%{buildroot}

# Drop in the bit of configuration
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make install -C ZTS INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Install the Apache configuration
install -D -m 644 httpd.conf %{buildroot}%{_sysconfdir}/httpd/conf.d/mysqlnd-qc-panel.conf

# Install the web interface
mkdir -p %{buildroot}%{_datadir}
cp -pr NTS/web %{buildroot}%{_datadir}/mysqlnd-qc

# Test & Documentation
for i in $(grep 'role="test"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_testdir}/%{pecl_name}/$i
done
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%post
%{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :


%postun
if [ $1 -eq 0 ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi


%check
cd NTS
# only check if build extension can be loaded
%{__php} -n -q \
    -d extension=mysqlnd.so \
    -d extension=sqlite3.so \
    -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_zts}
cd ../ZTS
# only check if build extension can be loaded
%{__ztsphp} -n -q \
    -d extension=mysqlnd.so \
    -d extension=sqlite3.so \
    -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}
%endif


%files
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%files devel
%doc %{pecl_testdir}/%{pecl_name}
%{_includedir}/php/ext/%{pecl_name}

%if %{with_zts}
%{php_ztsincldir}/ext/%{pecl_name}
%endif


%files -n %{?scl_prefix}mysqlnd-qc-panel
%{_sysconfdir}/httpd/conf.d/mysqlnd-qc-panel.conf
%{_datadir}/mysqlnd-qc


%changelog
* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Jun 19 2014 Remi Collet <rcollet@redhat.com> - 1.2.0-7
- rebuild for https://fedoraproject.org/wiki/Changes/Php56

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Apr 24 2014 Remi Collet <rcollet@redhat.com> - 1.2.0-5
- add numerical prefix to extension configuration file

* Sat Mar 22 2014  Remi Collet <remi@fedoraproject.org> - 1.2.0-4
- add PHP 5.6 patch
- move doc in pecl_docdir
- move tests in pecl_testdir (devel)
- create mysqlnd-qc-panel sub package
- fix typo in the config file

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Mar 22 2013 Remi Collet <rcollet@redhat.com> - 1.2.0-2
- rebuild for http://fedoraproject.org/wiki/Features/Php55

* Tue Mar 12 2013  Remi Collet <remi@fedoraproject.org> - 1.2.0-1
- update to 1.2.0-alpha
- also provides php-mysqlnd_qc

* Wed Feb 27 2013  Remi Collet <remi@fedoraproject.org> - 1.1.1-4.svn329586
- pull latest changes from SVN, fix FTBFS #914368

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Oct  9 2012  Remi Collet <remi@fedoraproject.org> - 1.1.1-2
- clean EL-5 stuff

* Mon Apr 30 2012  Remi Collet <remi@fedoraproject.org> - 1.1.1-1
- update to 1.1.1-alpha
- add devel sub-package
- update configuration file provided
  add collect_statistics-log-file and ignore_sql_comments
  remove apc_prefix (not supported in this build)

* Mon Jan 30 2012  Remi Collet <remi@fedoraproject.org> - 1.1.0-0.1.svn322926
- new snapshot, update to 1.1.0-alpha

* Mon Nov 21 2011  Remi Collet <remi@fedoraproject.org> - 1.0.1-3.svn322926
- fix from svn, build against php 5.4

* Sun Sep 18 2011  Remi Collet <remi@fedoraproject.org> - 1.0.1-2
- build zts extension

* Sun Sep 18 2011  Remi Collet <remi@fedoraproject.org> - 1.0.1-1
- Initial RPM
